instrumenttools.AltoTrombone
============================

.. abjad-lineage:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone

.. autoclass:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoTrombone.AltoTrombone.AltoTrombone.__repr__
   :noindex:
